Project::OSiRiON - Git repositories
Project::OSiRiON
News . About . Screenshots . Downloads . Forum . Wiki . Tracker . Git
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'src/render/textures.h')
-rw-r--r--src/render/textures.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/render/textures.h b/src/render/textures.h
index 69442e8..2341672 100644
--- a/src/render/textures.h
+++ b/src/render/textures.h
@@ -60,8 +60,8 @@ public:
/// list loaded textures
static void list();
- /// material loader func
- static void material_loader(model::Material *material);
+ /// material image loader hook
+ static void image_loader(model::Layer *layer);
private:
static void clear();